import React, { useEffect, useState } from "react";
import { Box, Button, Typography, Modal } from "@mui/material";
import CloseIcon from "@mui/icons-material/Close";
import { useForm, Controller } from "react-hook-form";
import {
	CustomIconButton,
	CustomTextField,
} from "../../AddUserModal/styled.css";

interface EditProfileModalProps {
	open: boolean;
	handleClose: () => void;
	handleUpdate: (
		name: string,
		phone: string,
		bio?: string,
		profilePhoto?: string | null
	) => void;
	editUser: any;
}

interface FormData {
	name: string;
	phone: string;
	bio?: string;
	profilePhoto?: string | null;
}


const EditProfileModal: React.FC<EditProfileModalProps> = ({
	open,
	handleClose,
	handleUpdate,
	editUser,
}) => {
	const {
		control,
		handleSubmit,
		formState: { errors },
		setValue,
		reset,
	} = useForm<FormData>();

	const [imagePreview, setImagePreview] = useState<string | null>(null);

	useEffect(() => {
		if (editUser) {
			setValue("name", editUser.name || "");
			setValue("phone", editUser.phone || "");
			setValue("bio", editUser.bio || "");
			setImagePreview(editUser.profilePhoto || null);
		}
	}, [editUser, setValue]);

	const handleImageChange = (e: React.ChangeEvent<HTMLInputElement>) => {
		const file = e.target.files?.[0];
		if (file) {
			const imageUrl = URL.createObjectURL(file);
			setImagePreview(imageUrl);
			setValue("profilePhoto", imageUrl);
		}
	};

	const handleModalClose = () => {
		handleClose();
		
	};

	const onSubmit = (data: FormData) => {
		console.log("Form Data:-----", data);
		handleUpdate(data.name, data.phone, data.bio, data.profilePhoto); 
        	reset();
		handleModalClose();
	};

	return (
		<Modal
			open={open}
			onClose={(e, reason) => {
				if (reason !== "backdropClick") handleModalClose();
			}}
			aria-labelledby="edit-profile-modal"
		>
			<Box
				component="form"
				onSubmit={handleSubmit(onSubmit)}
				sx={{
					position: "absolute",
					top: "50%",
					left: "50%",
					transform: "translate(-50%, -50%)",
					width: 500,
					boxShadow: 24,
					p: 0,
					borderRadius: 2,
				}}
			>
				{/* Header */}
				<Box
					sx={{
						display: "flex",
						justifyContent: "space-between",
						alignItems: "center",
						backgroundColor: "#000000",
						color: "#D0E1E9",
						padding: "20px 24px",
						borderRadius: "10px 10px 0 0",
					}}
				>
					<Typography variant="h6" fontWeight={600} fontSize="16px">
						Edit Profile
					</Typography>
					<CustomIconButton onClick={handleModalClose}>
						<CloseIcon />
					</CustomIconButton>
				</Box>

				<Box
					sx={{
						backgroundColor: "#b5c4cb",
						padding: "20px",
						borderRadius: "0 0 10px 10px",
					}}
				>
					<Box
						sx={{
							display: "flex",
							flexDirection: "column",
							gap: 2,
						}}
					>
						{/* Name Field */}
						<Box sx={{ display: "flex", flexDirection: "column" }}>
							<Typography
								variant="body2"
								fontWeight={500}
								color="#000000"
							>
								Full Name
							</Typography>
							<Controller
								name="name"
								control={control}
								rules={{
									required: "Name is required",
									minLength: {
										value: 3,
										message:
											"Minimum 3 characters required",
									},
									maxLength: {
										value: 30,
										message:
											"Maximum 30 characters allowed",
									},
									pattern: {
										value: /^[A-Za-z\s]+$/,
										message:
											"Only letters and spaces allowed",
									},
								}}
								render={({ field }) => (
									<CustomTextField
										{...field}
										fullWidth
										placeholder="Enter your name"
										size="small"
										sx={{ mt: 1 }}
										error={!!errors.name}
										helperText={errors.name?.message}
									/>
								)}
							/>
						</Box>

						{/* Phone Field */}
						<Box sx={{ display: "flex", flexDirection: "column" }}>
							<Typography
								variant="body2"
								fontWeight={500}
								color="#000000"
							>
								Phone Number
							</Typography>
							<Controller
								name="phone"
								control={control}
								rules={{
									required: "Phone number is required",
									validate: (value) => {
										if (!/^[0-9]*$/.test(value))
											return "Only numbers are allowed";
										if (value.length < 6)
											return "Must be at least 6 digits";
										if (value.length > 14)
											return "Must be at most 14 digits";
										return true;
									},
								}}
								render={({ field }) => (
									<CustomTextField
										{...field}
										fullWidth
										placeholder="Enter phone number"
										size="small"
										sx={{ mt: 1 }}
										error={!!errors.phone}
										helperText={errors.phone?.message}
									/>
								)}
							/>
						</Box>

						{/* Bio Field */}
						<Box sx={{ display: "flex", flexDirection: "column" }}>
							<Typography
								variant="body2"
								fontWeight={500}
								color="#000000"
							>
								Bio
							</Typography>
							<Controller
								name="bio"
								control={control}
								render={({ field }) => (
									<CustomTextField
										{...field}
										fullWidth
										placeholder="Add your bio details here..."
										size="small"
										sx={{ mt: 1 }}
									/>
								)}
							/>
						</Box>

						{/* Upload Image */}
						<Box sx={{ display: "flex", flexDirection: "column" }}>
							<Typography
								variant="body2"
								fontWeight={500}
								color="#000000"
							>
								Upload Profile Photo
							</Typography>
							<Button
								component="label"
								sx={{
									backgroundColor: "#000000",
									color: "#D0E1E9",
									borderRadius: "8px",
									mt: 1,
									"&:hover": { backgroundColor: "#454545" },
								}}
							>
								Choose Image
								<input
									type="file"
									hidden
									accept="image/*"
									onChange={handleImageChange}
								/>
							</Button>
							{imagePreview && (
								<Box mt={2}>
									<Typography variant="body2" color="#000000">
										Preview (
										{imagePreview.startsWith("blob")
											? "New"
											: "Existing"}
										):
									</Typography>
									<img
										src={imagePreview}
										alt="Profile Preview"
										style={{
											maxWidth: "40%",
											borderRadius: "8px",
										}}
									/>
								</Box>
							)}
						</Box>
					</Box>

					{/* Footer */}
					<Box
						sx={{
							display: "flex",
							justifyContent: "flex-end",
							mt: 3,
						}}
					>
						<Button
							type="submit"
							sx={{
								backgroundColor: "#000000",
								color: "#D0E1E9",
								borderRadius: "8px",
								fontSize: "16px",
								width: "140px",
								"&:hover": { backgroundColor: "#454545" },
							}}
						>
							Save Changes
						</Button>
					</Box>
				</Box>
			</Box>
		</Modal>
	);
};

export default EditProfileModal;
