import * as React from "react";
import { useDispatch, useSelector } from "react-redux";
import Card from "@mui/material/Card";
import CardContent from "@mui/material/CardContent";
import Typography from "@mui/material/Typography";
import Box from "@mui/material/Box";
import Select from "@mui/material/Select";
import MenuItem from "@mui/material/MenuItem";
import FormControl from "@mui/material/FormControl";
import ExpandMoreIcon from "@mui/icons-material/ExpandMore";
import { useTheme } from "@mui/material/styles";
import { fetchDashboardData } from "../../redux/slices/dashboardSlice";
import { RootState } from "../../redux/store/store"; // Adjust the path accordingly

export default function SessionsChart() {
	const theme = useTheme();
	const dispatch = useDispatch();
	const [selectedStation, setSelectedStation] = React.useState<string>("");

	// Get the dashboard data from Redux state
	const { basicPrice, loading } = useSelector(
		(state: RootState) => state.dashboardReducer
	);

	// Get unique station names from basicPrice for the dropdown
	const stationNames = Array.from(
		new Set(
			basicPrice?.map(
				(price: { stationName: string }) => price.stationName
			)
		)
	);

	// Set default station when basicPrice loads
	React.useEffect(() => {
		if (stationNames.length > 0 && !selectedStation) {
			setSelectedStation(stationNames[0]);
		}
	}, [basicPrice, stationNames, selectedStation]);

	// Handle station selection from dropdown
	const handleChange = (event: React.ChangeEvent<{ value: unknown }>) => {
		setSelectedStation(event.target.value as string);
	};

	// Filter basic prices for the selected station
	const selectedBasePrices =
		basicPrice?.filter(
			(price: { stationName: string }) =>
				price.stationName === selectedStation
		) || [];

	return (
		<Card
			variant="outlined"
			sx={{
				width: "100%",
				height: "auto",
				minHeight: { xs: "360px", sm: "400px", md: "421px" },
				gap: "16px",
				borderRadius: "30px",
				padding: { xs: "12px", sm: "16px", md: "20px" },
				border: "none",
				background: "#D0E1E9",
			}}
		>
			<CardContent
				sx={{
					flex: 1,
					padding: 0,
					"&:last-child": { paddingBottom: 0 },
					display: "flex",
					flexDirection: "column",
					justifyContent: "space-between",
				}}
			>
				<Typography
					variant="h6"
					align="left"
					sx={{
						fontWeight: 600,
						fontSize: { xs: "14px", sm: "16px", md: "20px" },
						lineHeight: "24px",
						letterSpacing: "0%",
						marginBottom: { xs: 1, sm: 0.7, md: 1 },
					}}
				>
					Charging prices
				</Typography>

				{/* Dropdown button */}
				<FormControl
					sx={{
						mt: { xs: 1, sm: 1.5, md: 2 },
						mb: { xs: 1, sm: 1.5, md: 2 },
						width: "100%",
						border: "1px solid rgba(87, 85, 85, 0.53)",
						borderRadius: "8px",
					}}
				>
					<Select
						value={selectedStation}
						onChange={handleChange}
						displayEmpty
						disabled={loading || stationNames.length === 0}
						sx={{
							color: "#000000",
							"& .MuiSvgIcon-root": { color: "#000000" },
							fontSize: { xs: "14px", md: "16px" },
						}}
						IconComponent={ExpandMoreIcon}
					>
						{stationNames.length === 0 && (
							<MenuItem value="" disabled>
								Loading stations...
							</MenuItem>
						)}
						{stationNames.map((name) => (
							<MenuItem key={name} value={name}>
								{name}
							</MenuItem>
						))}
					</Select>
				</FormControl>

				{/* Display the base prices for the selected station */}
				<Box
					sx={{
						display: "grid",
						gridTemplateColumns:
							selectedBasePrices.length === 1
								? "1fr"
								: "repeat(2, 1fr)",
						gap: { xs: 1, sm: 1.5, md: 2 },
						width: "100%",
					}}
				>
					{selectedBasePrices.length > 0 ? (
						selectedBasePrices.map(
							(price: {
								stationId: any;
								port: string;
								price: number;
							}) => (
								<Box
									key={`${price.stationId}-${price.port}`}
									sx={{
										height: {
											xs: "105px",
											sm: "115px",
											md: "128px",
										},
										borderRadius: "8px",
										p: {
											xs: "10px",
											sm: "12px",
											md: "14px",
										},
										backgroundColor: "#D9E7ED",
										display: "flex",
										flexDirection: "column",
										justifyContent: "center",
									}}
								>
									<Typography
										variant="body2"
										sx={{
											fontWeight: 600,
											fontSize: {
												xs: "12px",
												sm: "14px",
												md: "16px",
											},
											lineHeight: {
												xs: "20px",
												md: "24px",
											},
											marginBottom: "4px",
											color: "#111111",
										}}
										gutterBottom
									>
										{price.port}
									</Typography>
									<Box
										display="flex"
										gap={1}
										alignItems="center"
									>
										<Typography
											variant="subtitle2"
											sx={{
												fontWeight: 500,
												fontSize: {
													xs: "12px",
													sm: "14px",
													md: "16px",
												},
												lineHeight: {
													xs: "20px",
													md: "24px",
												},
											}}
											color="#454545"
											gutterBottom
										>
											{price.price.toFixed(2)}{" "}
										</Typography>
										<Typography
											sx={{
												fontWeight: 500,
												fontSize: {
													xs: "12px",
													sm: "14px",
													md: "16px",
												},
												lineHeight: {
													xs: "20px",
													md: "24px",
												},
											}}
											color="#454545"
										>
											(₹)/kWh
										</Typography>
									</Box>
								</Box>
							)
						)
					) : (
						<Typography
							variant="body2"
							sx={{
								fontSize: {
									xs: "12px",
									sm: "14px",
									md: "16px",
								},
								color: "#454545",
								textAlign: "center",
								gridColumn: "span 2",
							}}
						>
							No pricing data available for this station.
						</Typography>
					)}
				</Box>
			</CardContent>
		</Card>
	);
}
