import React from "react";
import { Card, CardContent, Typography, Box, Stack } from "@mui/material";
import { PieChart } from "@mui/x-charts/PieChart";
import { useTheme } from "@mui/material/styles";
import useMediaQuery from "@mui/material/useMediaQuery";

export default function StaticResourcePieChart() {
	const theme = useTheme();
	const isXsScreen = useMediaQuery(theme.breakpoints.down("sm"));
	const isSmScreen = useMediaQuery(theme.breakpoints.between("sm", "md"));

	const kwhData = [
		{ stationId: "Indian Charging Station", kwh: 500 },
		{ stationId: "Mumbai Charging Station", kwh: 300 },
		{ stationId: "Delhi Charging Station", kwh: 450 },
		{ stationId: "Tata Charging Station", kwh: 200 },
		{ stationId: "PlugIn Charging Station", kwh: 350 },
	];

	const customColors = [
		"rgb(11, 13, 14)",
		"hsl(204, 59.60%, 78.60%)",
		"hsl(214, 77.50%, 13.90%)",
		"hsl(222, 4.10%, 52.20%)",
		"hsl(220, 40.30%, 71.80%)",
	];

	// Function to determine chart dimensions based on screen size
	const getChartDimensions = () => {
		if (isXsScreen) {
			return {
				height: 240,
				width: 240,
				margin: { left: 20, right: 20, top: 40, bottom: 40 },
			};
		} else if (isSmScreen) {
			return {
				height: 260,
				width: 260,
				margin: { left: 40, right: 40, top: 60, bottom: 60 },
			};
		} else {
			return {
				height: 350,
				width: 350,
				margin: { left: 60, right: 80, top: 80, bottom: 80 },
			};
		}
	};

	const dimensions = getChartDimensions();

	return (
		<Card
			variant="outlined"
			sx={{
				display: "flex",
				flexDirection: "column",
				gap: { xs: "8px", sm: "10px", md: "12px" },
				flexGrow: 1,
				width: "100%",
				height: "auto",
				minHeight: { xs: "320px", sm: "340px", md: "470px" },
				padding: { xs: "12px", sm: "14px", md: "16px" },
				borderRadius: "30px",
				border: "none",
				background: "#D0E1E9",
			}}
		>
			<CardContent
				sx={{ padding: 0, "&:last-child": { paddingBottom: 0 } }}
			>
				<Typography
					component="h2"
					variant="subtitle2"
					sx={{
						fontWeight: 600,
						fontSize: { xs: "12px", sm: "14px", md: "16px" },
						lineHeight: "24px",
						marginBottom: { xs: 1, sm: 1.5, md: 2 },
					}}
				>
					KWh Consumed by Station
				</Typography>
				<Box
					sx={{
						display: "flex",
						flexDirection: { xs: "column", sm: "row" },
						alignItems: "center",
						justifyContent: "center",
					}}
				>
					<PieChart
						colors={customColors}
						margin={dimensions.margin}
						series={[
							{
								data: kwhData.map((d, i) => ({
									id: i,
									value: d.kwh,
									label: d.stationId,
									color: customColors[
										i % customColors.length
									],
								})),

								paddingAngle: 2,
								cornerRadius: 8,
								highlightScope: {
									faded: "global",
									highlighted: "item",
								},
							},
						]}
						height={dimensions.height}
						width={dimensions.width}
						slotProps={{
							legend: { hidden: true }, // Hide default legend
						}}
					/>
					<Stack
						spacing={1}
						sx={{
							mt: { xs: 2, sm: 0 },
							ml: { xs: 0, sm: 2 },
						}}
					>
						<Typography sx={{ whiteSpace: "pre", fontWeight: 500 }}>
							Charging Stations:
						</Typography>
						{kwhData.map((entry, index) => (
							<Stack
								key={index}
								direction="row"
								spacing={1}
								alignItems="center"
							>
								<Box
									sx={{
										width: { xs: 12, sm: 14, md: 16 },
										height: { xs: 12, sm: 14, md: 16 },
										backgroundColor:
											customColors[
												index % customColors.length
											],
										borderRadius: "50%",
									}}
								/>
								<Typography
									variant="body2"
									sx={{
										fontSize: {
											xs: "12px",
											sm: "14px",
											md: "16px",
										},
										color: "#111111",
									}}
								>
									{entry.stationId}
								</Typography>
							</Stack>
						))}
					</Stack>
				</Box>
			</CardContent>
		</Card>
	);
}
