import { createSlice, createAsyncThunk, PayloadAction } from "@reduxjs/toolkit";
import http from "../../lib/https";
import { toast } from "sonner";

interface CarPortCount {
	carPort: string;
	count: number;
}

interface TopStation {
	stationId: number;
	count: string;
	ChargingStation: {
		id: number;
		name: string;
	};
}

interface BasicPrice {
	port: string;
	price: number;
	stationId: number;
	stationName: string; 
}

interface DashboardState {
	totalAdmins?: number;
	totalManagers?: number;
	totalUsers?: number;
	totalStations?: number;
	carPortCounts?: CarPortCount[];
	topStations?: TopStation[];
	basicPrice?: BasicPrice[];
	totalBookings?: number;
	loading: boolean;
	error: string | null;
}

const initialState: DashboardState = {
	totalAdmins: 0,
	totalManagers: 0,
	totalUsers: 0,
	totalStations: 0,
	carPortCounts: [],
	topStations: [],
	basicPrice: [],
	totalBookings: 0,
	loading: false,
	error: null,
};

// Async thunk for fetching dashboard data
export const fetchDashboardData = createAsyncThunk<
	DashboardState,
	{
		startDateBookings?: string;
		endDateBookings?: string;
		startDateStations?: string;
		endDateStations?: string;
	},
	{ rejectValue: string }
>("dashboard/fetchDashboardData", async (params, { rejectWithValue }) => {
	try {
		const response = await http.get("/dashboard", { params });
		return response.data as DashboardState; // Ensure response matches DashboardState
	} catch (error: any) {
		toast.error("Error Fetching Dashboard Data: " + error.message);
		return rejectWithValue(
			error?.response?.data?.message || "An error occurred"
		);
	}
});

// Redux slice for the dashboard
const dashboardSlice = createSlice({
	name: "dashboard",
	initialState,
	reducers: {},
	extraReducers: (builder) => {
		builder
			.addCase(fetchDashboardData.pending, (state) => {
				state.loading = true;
				state.error = null;
			})
			.addCase(
				fetchDashboardData.fulfilled,
				(state, action: PayloadAction<DashboardState>) => {
					state.loading = false;
					// Map response fields to state
					state.totalAdmins = action.payload.totalAdmins ?? 0;
					state.totalManagers = action.payload.totalManagers ?? 0;
					state.totalUsers = action.payload.totalUsers ?? 0;
					state.totalStations = action.payload.totalStations ?? 0;
					state.carPortCounts = action.payload.carPortCounts ?? [];
					state.topStations = action.payload.topStations ?? [];
					state.basicPrice = action.payload.basicPrice ?? [];
					state.totalBookings = action.payload.totalBookings ?? 0;
				}
			)
			.addCase(fetchDashboardData.rejected, (state, action) => {
				state.loading = false;
				state.error =
					action.payload || "Failed to fetch dashboard data";
			});
	},
});

export default dashboardSlice.reducer;
