import { createSlice, createAsyncThunk } from "@reduxjs/toolkit";
import http from "../../lib/https";
import { toast } from "sonner";
import { string } from "prop-types";

interface User {
	token: string | null;
	id: string;
	name: string;
	email: string;
	userType: string;
	phone: string;
	bio?: string;
	profilePhoto?: string;
}

interface AuthState {
	user: User | null;
	users: User[];
	isAuthenticated: boolean;
	loading: boolean;
	error: null | string;
}

const initialState: AuthState = {
	users: [],
	loading: false,
	error: null,
	isAuthenticated: false,
	user: null,
};

export const fetchAdminProfile = createAsyncThunk<
	User,
	void,
	{ rejectValue: string }
>("GetAdminProfile", async (_, { rejectWithValue }) => {
	try {
		const token = localStorage?.getItem("authToken");
		if (!token) throw new Error("No token found");

		const response = await http.get("/profile");

		if (!response.data?.data) throw new Error("Invalid API response");

		return response.data.data;
	} catch (error: any) {
		toast.error("Error Fetching Profile: " + error.message);
		return rejectWithValue(
			error?.response?.data?.message || "An error occurred"
		);
	}
});

export const updateProfile = createAsyncThunk<
	User, 
	{
		name: string;
		phone?: string;
		bio?: string;
		profilePhoto?: string | null;
	},
	{ rejectValue: string }
>(
	"updateProfile",
	async ({ name, phone, bio, profilePhoto }, { rejectWithValue }) => {
		try {
			const payload: any = { name };
			if (phone) payload.phone = phone;
			if (bio) payload.bio = bio;
			if (profilePhoto) payload.profilePhoto = profilePhoto;
			
			const response = await http.put("/edit-profile", payload);
			console.log("-----------", response);

			toast.success("Profile updated successfully");
			return response.data.data;
		} catch (error: any) {
			toast.error("Error updating the profile: " + error.message);
			return rejectWithValue(
				error?.response?.data?.message || "An error occurred"
			);
		}
	}
);


const profileSlice = createSlice({
	name: "profile",
	initialState,
	reducers: {},
	extraReducers: (builder) => {
		builder
			.addCase(fetchAdminProfile.pending, (state) => {
				state.loading = true;
			})
			.addCase(fetchAdminProfile.fulfilled, (state, action) => {
				state.loading = false;
				state.user = action.payload;
				state.isAuthenticated = true;
			})
			.addCase(fetchAdminProfile.rejected, (state, action) => {
				state.loading = false;
				state.error = action.payload;
			})
			.addCase(updateProfile.fulfilled, (state, action) => {
				state.loading = false;
				state.user = action.payload; // Update current user only
				toast.success("Profile Details updated successfully");
			})

			.addCase(updateProfile.rejected, (state, action) => {
				state.loading = false;
				state.error = action.payload;
			})
			.addCase(updateProfile.pending, (state) => {
				state.loading = true;
			});
	},
});

export default profileSlice.reducer;
